@@ -14,11 +14,11 @@ C<Math::Geometry::Construction::Derivate::IntersectionCircleCircle> - circle cir
 
 =head1 VERSION
 
-Version 0.017
+Version 0.018
 
 =cut
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 
 ###########################################################################
@@ -33,7 +33,7 @@ our $VERSION = '0.017';
 #                                                                         #
 ###########################################################################
 
-sub positions {
+sub calculate_positions {
     my ($self)  = @_;
     my @circles = $self->input;
 
@@ -100,17 +100,6 @@ __END__
 
 =head2 Methods for Subclass Developers
 
-=head1 DIAGNOSTICS
-
-=head2 Exceptions
-
-=head2 Warnings
-
-
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported. Please report all bugs directly to the author.
-
 
 =head1 AUTHOR
 
