@@ -12,11 +12,11 @@ C<Math::Geometry::Construction::Derivate::PointOnLine> - point on a line
 
 =head1 VERSION
 
-Version 0.017
+Version 0.018
 
 =cut
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 
 ###########################################################################
@@ -58,6 +58,8 @@ sub _rules {
 	    $self->$clearer;
 	}
     }
+
+    $self->clear_global_buffer;
 }
 
 sub _distance_rules { $_[0]->_rules('distance') }
@@ -81,7 +83,7 @@ sub BUILD {
 #                                                                         #
 ###########################################################################
 
-sub positions {
+sub calculate_positions {
     my ($self) = @_;
     my @input  = $self->input;
 
@@ -157,17 +159,6 @@ __END__
 
 =head2 Methods for Subclass Developers
 
-=head1 DIAGNOSTICS
-
-=head2 Exceptions
-
-=head2 Warnings
-
-
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported. Please report all bugs directly to the author.
-
 
 =head1 AUTHOR
 
