@@ -9,17 +9,21 @@ use List::MoreUtils qw(any);
 use Scalar::Util qw(blessed);
 use Math::Vector::Real;
 
+use overload 'x'    => '_intersect',
+             '.'    => '_point_on',
+             'bool' => sub { return 1 };
+
 =head1 NAME
 
 C<Math::Geometry::Construction::Line> - line through two points
 
 =head1 VERSION
 
-Version 0.019
+Version 0.020
 
 =cut
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 
 ###########################################################################
@@ -124,10 +128,11 @@ sub draw {
     my $parallel = $self->parallel;
     return undef if(!$parallel);
 
+    my $extend    = $self->extend;
     my @positions = ($self->extreme_position(-$parallel)
-		     - $parallel * $self->extend,
+		     - $parallel * $extend->[0],
 		     $self->extreme_position($parallel)
-		     + $parallel * $self->extend);
+		     + $parallel * $extend->[1]);
 
     $self->construction->draw_line(x1    => $positions[0]->[0],
 				   y1    => $positions[0]->[1],
@@ -143,10 +148,35 @@ sub draw {
 
 ###########################################################################
 #                                                                         #
-#                              Change Data                                # 
+#                              Overloading                                # 
 #                                                                         #
 ###########################################################################
 
+sub _intersect {
+    my ($self, $intersector) = @_;
+    my $class;
+	 
+    $class = 'Math::Geometry::Construction::Line';
+    if(eval { $intersector->isa($class) }) {
+	return $self->construction->add_derived_point
+	    ('IntersectionLineLine', {input => [$self, $intersector]});
+    }
+
+    $class = 'Math::Geometry::Construction::Circle';
+    if(eval { $intersector->isa($class) }) {
+	return $self->construction->add_derived_point
+	    ('IntersectionCircleLine', {input => [$self, $intersector]});
+    }
+}
+
+sub _point_on {
+    my ($self, $args) = @_;
+
+    my $derivate = "Math::Geometry::Construction::Derivate::PointOnLine";
+    return $self->construction->add_derived_point
+	($derivate, {input => [$self], $args});
+}
+
 1;
 
 
@@ -197,7 +227,14 @@ hold exactly two points.
 
 Often it looks nicer if the visual representation of a line extends
 somewhat beyond its end points. The length of this extent is set
-here. Defaults to C<0>.
+here. Internally, this is an array reference with two entries
+containing the exent in backward in forward direction. If a single
+value C<x> is provided it is turned into C<[x, x]>. Defaults to
+C<[0, 0]>.
+
+Take care if you are reading this attribute. You get the internal
+array reference, so manipulating it will affect the values stored in
+the object.
 
 =head2 Methods
 
@@ -226,7 +263,7 @@ Lutz Gehlen, C<< <perl at lutzgehlen.de> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Lutz Gehlen.
+Copyright 2011-2012 Lutz Gehlen.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
